package ch.epfl.alpano;

import static java.lang.Float.POSITIVE_INFINITY;
import static java.lang.Math.PI;
import static java.lang.Math.cos;
import static java.lang.Math.sin;
import static java.lang.Math.toRadians;
import static org.junit.Assert.assertEquals;

import java.io.IOException;
import java.util.function.DoubleUnaryOperator;

import org.junit.Test;

import ch.epfl.alpano.dem.ContinuousElevationModel;
import ch.epfl.alpano.dem.DiscreteElevationModel;
import ch.epfl.alpano.dem.ElevationProfile;

public class PanoramaComputerTest {
    @Test(expected = NullPointerException.class)
    public void constructorFailsWithNullDEM() {
        new PanoramaComputer(null);
    }

    @Test
    public void computePanoramaWorksOnFlatTerrain() {
        int w = 50, h = 20;
        GeoPoint o = new GeoPoint(0,0);
        PanoramaParameters pp = new PanoramaParameters(o, 100, toRadians(45), toRadians(h), 300_000, w, h);
        PanoramaComputer pc = new PanoramaComputer(zeroContDEM());
        Panorama p = pc.computePanorama(pp);
        for (int y = 0; y < h; ++y) {
            float d = p.distanceAt(0, y);
            float hDist = (float) o.distanceTo(new GeoPoint(p.longitudeAt(0, y), p.latitudeAt(0, y)));
            for (int x = 1; x < w; ++x) {
                assertEquals(d, p.distanceAt(x, y), 1e-6);
                assertEquals(hDist, (float) o.distanceTo(new GeoPoint(p.longitudeAt(x, y), p.latitudeAt(x, y))), 1e-2);
                assertEquals(0, p.slopeAt(x, y), 1e-6);
                assertEquals(0, p.elevationAt(x, y), 1e-6);
            }
        }
    }

    @Test
    public void computePanoramaWorksOnHillyTerrain() throws IOException {
        int w = 50, h = 20;
        GeoPoint o = new GeoPoint(0,0);
        PanoramaParameters pp = new PanoramaParameters(o, 2000, toRadians(45), toRadians(h), 300_000, w, h);
        PanoramaComputer pc = new PanoramaComputer(wavyContDEM());
        Panorama p = pc.computePanorama(pp);
        int i = 0;
        for (int x = 0; x < w; ++x) {
            for (int y = 0; y < h; ++y) {
                assertEquals(WAVY_EXPECTED_DATA[i++], p.distanceAt(x, y), 1e-5);
                assertEquals(WAVY_EXPECTED_DATA[i++], p.longitudeAt(x, y), 1e-5);
                assertEquals(WAVY_EXPECTED_DATA[i++], p.latitudeAt(x, y), 1e-5);
                assertEquals(WAVY_EXPECTED_DATA[i++], p.elevationAt(x, y), 1e-5);
                assertEquals(WAVY_EXPECTED_DATA[i++], p.slopeAt(x, y), 1e-5);
            }
        }
    }

    @Test
    public void rayToGroundDistanceAccountsForEarthCurvatureAndRefraction() {
        double dropPerM2 = (1d - 0.13d) / (2d * 6_371_000d);
        double startingElevation = 1_000;
        ElevationProfile p = new ElevationProfile(zeroContDEM(), new GeoPoint(0,0), toRadians(45), 100_000);
        DoubleUnaryOperator rToG = PanoramaComputer.rayToGroundDistance(p, startingElevation, 1);
        for (int k = 0; k < 100; ++k) {
            double m = k * 1000d;
            double d = rToG.applyAsDouble(m);
            double expD = startingElevation + m + dropPerM2 * m * m;
            assertEquals(expD, d, 1e-6);
        }
    }

    private static Interval2D positiveQuadrant() {
        return new Interval2D(
                new Interval1D(0, 3600 * 179),
                new Interval1D(0, 3600 * 89));
    }

    private static ContinuousElevationModel zeroContDEM() {
        return new ContinuousElevationModel(new ZeroDEM(positiveQuadrant()));
    }

    private static ContinuousElevationModel wavyContDEM() {
        return new ContinuousElevationModel(new WavyDEM(positiveQuadrant()));
    }

    private final static class ZeroDEM implements DiscreteElevationModel {
        private final Interval2D extent;

        public ZeroDEM(Interval2D extent) { this.extent = extent; }

        @Override
        public void close() throws Exception { }

        @Override
        public Interval2D extent() { return extent; }

        @Override
        public double elevationSample(int x, int y) {
            if (! extent.contains(x, y))
                throw new IllegalArgumentException();
            return 0;
        }
    }

    private final static class WavyDEM implements DiscreteElevationModel {
        private final static double PERIOD = 100, HEIGHT = 1000;
        private final Interval2D extent;

        public WavyDEM(Interval2D extent) { this.extent = extent; }

        @Override
        public void close() throws Exception { }

        @Override
        public Interval2D extent() { return extent; }

        @Override
        public double elevationSample(int x, int y) {
            if (! extent.contains(x, y))
                throw new IllegalArgumentException();
            double x1 = PI * 2d * x / PERIOD;
            double y1 = PI * 2d * y / PERIOD;
            return (1 + sin(x1) * cos(y1)) / 2d * HEIGHT;
        }
    }

    private static float[] WAVY_EXPECTED_DATA = new float[] {
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            84709.437500f, 0.007625f, 0.010890f, 980.874390f, 0.229993f,
            46998.609375f, 0.004230f, 0.006041f, 978.326904f, 0.245936f,
            35958.476563f, 0.003236f, 0.004621f, 935.190247f, 0.444532f,
            33381.621094f, 0.003003f, 0.004289f, 766.546753f, 0.668034f,
            22712.343750f, 0.002043f, 0.002917f, 983.481079f, 0.239640f,
            20533.300781f, 0.001846f, 0.002636f, 932.034180f, 0.457185f,
            20225.066406f, 0.001818f, 0.002596f, 803.654175f, 0.666944f,
            20053.906250f, 0.001801f, 0.002573f, 668.763062f, 0.744808f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            88970.109375f, 0.008090f, 0.011380f, 954.825989f, 0.361675f,
            49051.246094f, 0.004460f, 0.006273f, 939.848450f, 0.404510f,
            35770.378906f, 0.003251f, 0.004574f, 940.322388f, 0.405079f,
            33525.730469f, 0.003047f, 0.004286f, 761.193665f, 0.694433f,
            22628.253906f, 0.002056f, 0.002892f, 986.522827f, 0.192340f,
            22331.867188f, 0.002028f, 0.002853f, 841.012939f, 0.583702f,
            20349.294922f, 0.001847f, 0.002599f, 795.799744f, 0.646637f,
            20146.117188f, 0.001828f, 0.002571f, 664.645447f, 0.755159f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            91150.453125f, 0.008371f, 0.011600f, 943.764160f, 0.417762f,
            51135.894531f, 0.004696f, 0.006506f, 902.993286f, 0.490020f,
            37831.437500f, 0.003473f, 0.004813f, 883.724915f, 0.520753f,
            35507.250000f, 0.003259f, 0.004516f, 694.336121f, 0.737231f,
            24610.378906f, 0.002258f, 0.003129f, 900.568359f, 0.504919f,
            22383.941406f, 0.002053f, 0.002845f, 836.146790f, 0.627400f,
            22192.673828f, 0.002035f, 0.002819f, 689.132507f, 0.719115f,
            20266.392578f, 0.001857f, 0.002574f, 656.678284f, 0.698565f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            82277.046875f, 0.007631f, 0.010416f, 996.500122f, 0.073279f,
            53232.546875f, 0.004936f, 0.006738f, 865.387634f, 0.550727f,
            37883.464844f, 0.003512f, 0.004794f, 883.081665f, 0.560125f,
            35711.406250f, 0.003310f, 0.004518f, 687.718384f, 0.692531f,
            24578.345703f, 0.002277f, 0.003109f, 902.781189f, 0.496127f,
            22520.134766f, 0.002086f, 0.002847f, 830.693665f, 0.618434f,
            22284.841797f, 0.002063f, 0.002817f, 682.675110f, 0.751056f,
            20502.933594f, 0.001897f, 0.002590f, 641.667542f, 0.576057f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            86489.718750f, 0.008099f, 0.010892f, 970.195984f, 0.289091f,
            55349.203125f, 0.005182f, 0.006969f, 828.992981f, 0.603511f,
            39928.515625f, 0.003738f, 0.005027f, 827.423218f, 0.623469f,
            37704.937500f, 0.003529f, 0.004746f, 617.703003f, 0.767411f,
            24650.421875f, 0.002306f, 0.003102f, 899.107300f, 0.530999f,
            24402.822266f, 0.002282f, 0.003069f, 734.731262f, 0.703732f,
            22421.091797f, 0.002096f, 0.002819f, 676.315125f, 0.702311f,
            22218.861328f, 0.002076f, 0.002792f, 528.865723f, 0.781119f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            90746.390625f, 0.008579f, 0.011367f, 945.027588f, 0.387835f,
            57493.871094f, 0.005435f, 0.007201f, 791.839111f, 0.660696f,
            40212.660156f, 0.003800f, 0.005036f, 821.024170f, 0.604822f,
            27012.732422f, 0.002552f, 0.003382f, 991.600220f, 0.174015f,
            26612.525391f, 0.002514f, 0.003331f, 813.463379f, 0.616118f,
            24518.988281f, 0.002315f, 0.003068f, 730.185791f, 0.719989f,
            24312.558594f, 0.002295f, 0.003040f, 566.682190f, 0.783679f,
            22335.128906f, 0.002107f, 0.002792f, 522.528809f, 0.695462f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            95031.070313f, 0.009069f, 0.011840f, 923.181885f, 0.453928f,
            59682.550781f, 0.005694f, 0.007435f, 754.838440f, 0.708352f,
            42221.691406f, 0.004028f, 0.005259f, 766.381897f, 0.671755f,
            28934.207031f, 0.002759f, 0.003603f, 923.640625f, 0.446930f,
            26704.623047f, 0.002546f, 0.003324f, 809.871643f, 0.660757f,
            24735.296875f, 0.002357f, 0.003078f, 720.623901f, 0.632081f,
            24440.792969f, 0.002328f, 0.003040f, 560.574707f, 0.759868f,
            22455.404297f, 0.002138f, 0.002792f, 514.150757f, 0.497022f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            84117.335938f, 0.008102f, 0.010423f, 984.818420f, 0.214339f,
            48763.156250f, 0.004696f, 0.006041f, 945.669739f, 0.389533f,
            44322.773438f, 0.004267f, 0.005490f, 711.922180f, 0.711195f,
            29006.261719f, 0.002792f, 0.003592f, 919.419861f, 0.486024f,
            26964.902344f, 0.002595f, 0.003338f, 801.177917f, 0.613099f,
            26605.964844f, 0.002559f, 0.003293f, 626.105164f, 0.764760f,
            24589.064453f, 0.002364f, 0.003042f, 552.338623f, 0.616470f,
            22607.751953f, 0.002173f, 0.002795f, 505.691284f, 0.154827f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            88330.007813f, 0.008585f, 0.010884f, 958.602844f, 0.340961f,
            50839.800781f, 0.004940f, 0.006263f, 906.774475f, 0.484590f,
            46463.871094f, 0.004514f, 0.005723f, 656.460205f, 0.725354f,
            31011.800781f, 0.003012f, 0.003819f, 848.278748f, 0.599455f,
            28842.916016f, 0.002801f, 0.003551f, 720.584229f, 0.724787f,
            26790.228516f, 0.002600f, 0.003297f, 617.183167f, 0.645136f,
            26524.613281f, 0.002574f, 0.003263f, 441.893066f, 0.757542f,
            15888.371094f, 0.001541f, 0.001954f, 942.336914f, 0.424136f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            92666.695313f, 0.009088f, 0.011354f, 935.550110f, 0.439005f,
            52980.468750f, 0.005195f, 0.006490f, 870.357300f, 0.567916f,
            35514.246094f, 0.003482f, 0.004350f, 946.784302f, 0.391668f,
            31207.951172f, 0.003059f, 0.003821f, 843.929810f, 0.599462f,
            30865.083984f, 0.003024f, 0.003778f, 633.433533f, 0.768677f,
            28749.023438f, 0.002816f, 0.003518f, 518.472107f, 0.758389f,
            26632.810547f, 0.002607f, 0.003258f, 433.909332f, 0.617342f,
            15764.085938f, 0.001543f, 0.001927f, 949.185913f, 0.384576f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            99107.718750f, 0.009806f, 0.012073f, 904.829590f, 0.509428f,
            55189.152344f, 0.005459f, 0.006722f, 830.768311f, 0.637049f,
            35534.257813f, 0.003514f, 0.004327f, 946.171204f, 0.405594f,
            33225.500000f, 0.003285f, 0.004045f, 773.468018f, 0.688757f,
            31057.289063f, 0.003070f, 0.003780f, 625.890015f, 0.705308f,
            28913.257813f, 0.002857f, 0.003518f, 511.646362f, 0.564084f,
            18000.990234f, 0.001778f, 0.002189f, 931.622803f, 0.454050f,
            15736.022461f, 0.001554f, 0.001913f, 951.512146f, 0.366696f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            85985.632813f, 0.008582f, 0.010414f, 973.038086f, 0.280072f,
            57549.886719f, 0.005743f, 0.006969f, 790.780701f, 0.620688f,
            37611.324219f, 0.003752f, 0.004554f, 889.287964f, 0.547304f,
            35311.101563f, 0.003522f, 0.004274f, 699.980103f, 0.740743f,
            33111.492188f, 0.003302f, 0.004007f, 541.326294f, 0.753893f,
            29097.521484f, 0.002900f, 0.003520f, 503.391663f, 0.128561f,
            17896.800781f, 0.001783f, 0.002164f, 937.554626f, 0.417286f,
            15764.085938f, 0.001570f, 0.001905f, 950.638062f, 0.386320f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            90306.320313f, 0.009091f, 0.010873f, 947.402954f, 0.402091f,
            61739.191406f, 0.006214f, 0.007432f, 719.618591f, 0.690675f,
            39740.417969f, 0.003999f, 0.004783f, 832.015930f, 0.635650f,
            37436.730469f, 0.003766f, 0.004505f, 627.783569f, 0.769014f,
            33331.726563f, 0.003352f, 0.004009f, 532.232605f, 0.484202f,
            20152.757813f, 0.002026f, 0.002423f, 950.907593f, 0.389268f,
            17880.771484f, 0.001797f, 0.002149f, 939.077454f, 0.408996f,
            15872.333984f, 0.001594f, 0.001907f, 943.162537f, 0.422670f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            96867.359375f, 0.009834f, 0.011593f, 915.189697f, 0.494122f,
            46478.445313f, 0.004718f, 0.005562f, 988.397827f, 0.171071f,
            41917.535156f, 0.004254f, 0.005015f, 774.732239f, 0.688595f,
            37768.988281f, 0.003832f, 0.004517f, 617.289612f, 0.560127f,
            35361.902344f, 0.003587f, 0.004228f, 446.420929f, 0.554925f,
            20084.660156f, 0.002036f, 0.002401f, 953.957886f, 0.358164f,
            17928.859375f, 0.001817f, 0.002142f, 935.491882f, 0.440060f,
            17728.583984f, 0.001796f, 0.002117f, 821.576965f, 0.625772f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            105528.734375f, 0.010803f, 0.012553f, 880.221680f, 0.561564f,
            48627.113281f, 0.004977f, 0.005783f, 948.793945f, 0.401526f,
            44154.687500f, 0.004518f, 0.005250f, 717.608459f, 0.688609f,
            39878.605469f, 0.004080f, 0.004741f, 545.315247f, 0.486779f,
            22424.035156f, 0.002293f, 0.002665f, 995.897339f, 0.097740f,
            20120.710938f, 0.002057f, 0.002390f, 952.452393f, 0.381526f,
            19884.443359f, 0.002032f, 0.002361f, 820.711365f, 0.615344f,
            17804.757813f, 0.001819f, 0.002113f, 816.742432f, 0.653792f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            87937.945313f, 0.009077f, 0.010396f, 960.889404f, 0.335697f,
            52844.425781f, 0.005453f, 0.006246f, 872.692200f, 0.578334f,
            46515.898438f, 0.004799f, 0.005497f, 656.296753f, 0.589188f,
            41980.218750f, 0.004330f, 0.004960f, 474.686859f, 0.410988f,
            24350.099609f, 0.002511f, 0.002876f, 910.907471f, 0.473740f,
            22103.541016f, 0.002278f, 0.002610f, 852.462280f, 0.583186f,
            19964.589844f, 0.002057f, 0.002356f, 818.702576f, 0.650674f,
            17941.070313f, 0.001848f, 0.002116f, 807.424194f, 0.635033f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            96599.320313f, 0.010052f, 0.011349f, 916.317322f, 0.486529f,
            57169.769531f, 0.005948f, 0.006715f, 795.605103f, 0.672823f,
            50662.031250f, 0.005270f, 0.005950f, 551.013855f, 0.636660f,
            26800.568359f, 0.002787f, 0.003147f, 998.917419f, 0.045095f,
            24390.142578f, 0.002536f, 0.002863f, 909.955872f, 0.499872f,
            22199.677734f, 0.002307f, 0.002605f, 847.734375f, 0.615918f,
            20112.861328f, 0.002089f, 0.002359f, 809.199280f, 0.635007f,
            19885.521484f, 0.002065f, 0.002331f, 679.317627f, 0.752212f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            107501.046875f, 0.011276f, 0.012549f, 873.613220f, 0.577404f,
            61615.152344f, 0.006462f, 0.007192f, 721.797485f, 0.675672f,
            52943.203125f, 0.005551f, 0.006178f, 493.818878f, 0.307838f,
            28758.070313f, 0.003015f, 0.003355f, 929.724976f, 0.443388f,
            26456.357422f, 0.002772f, 0.003086f, 823.046204f, 0.634712f,
            24246.599609f, 0.002540f, 0.002827f, 742.787415f, 0.716020f,
            22108.519531f, 0.002315f, 0.002577f, 694.804260f, 0.739458f,
            20029.851563f, 0.002096f, 0.002333f, 671.392578f, 0.703196f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            83545.250000f, 0.008832f, 0.009690f, 987.967041f, 0.178243f,
            68133.179688f, 0.007202f, 0.007901f, 616.913208f, 0.664916f,
            35330.152344f, 0.003734f, 0.004096f, 952.693237f, 0.362734f,
            30855.681641f, 0.003260f, 0.003577f, 854.038452f, 0.598354f,
            26632.546875f, 0.002813f, 0.003086f, 814.743591f, 0.635395f,
            24430.861328f, 0.002579f, 0.002830f, 735.936523f, 0.677867f,
            22304.878906f, 0.002354f, 0.002583f, 683.919678f, 0.649697f,
            22046.466797f, 0.002326f, 0.002552f, 539.665039f, 0.768107f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            92230.625000f, 0.009827f, 0.010628f, 937.008606f, 0.439230f,
            74739.226563f, 0.007962f, 0.008611f, 516.859985f, 0.447982f,
            37447.238281f, 0.003988f, 0.004314f, 894.911438f, 0.530319f,
            33025.347656f, 0.003516f, 0.003803f, 780.207275f, 0.688662f,
            28766.833984f, 0.003062f, 0.003312f, 723.327942f, 0.690264f,
            26525.851563f, 0.002822f, 0.003053f, 630.247864f, 0.720273f,
            24336.601563f, 0.002588f, 0.002800f, 565.519897f, 0.705024f,
            22190.798828f, 0.002359f, 0.002552f, 530.738708f, 0.646628f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            109629.382813f, 0.011770f, 0.012549f, 867.613464f, 0.583372f,
            48435.054688f, 0.005199f, 0.005544f, 951.460571f, 0.374928f,
            39704.398438f, 0.004261f, 0.004543f, 834.850647f, 0.622421f,
            35263.062500f, 0.003783f, 0.004034f, 703.213989f, 0.713794f,
            30957.181641f, 0.003320f, 0.003540f, 632.041565f, 0.673794f,
            28660.898438f, 0.003073f, 0.003277f, 522.910034f, 0.710446f,
            24569.027344f, 0.002633f, 0.002808f, 553.573730f, 0.441540f,
            22363.193359f, 0.002396f, 0.002554f, 521.337341f, 0.362100f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            138073.890625f, 0.014937f, 0.015699f, 841.810730f, 0.601888f,
            52832.421875f, 0.005714f, 0.006006f, 872.735962f, 0.572631f,
            44078.648438f, 0.004766f, 0.005010f, 719.575928f, 0.672822f,
            37584.843750f, 0.004063f, 0.004271f, 624.045227f, 0.607553f,
            33159.542969f, 0.003584f, 0.003767f, 538.927979f, 0.569105f,
            28865.189453f, 0.003118f, 0.003278f, 514.432617f, 0.400636f,
            26540.642578f, 0.002866f, 0.003013f, 441.189240f, 0.511416f,
            24299.625000f, 0.002623f, 0.002757f, 396.554291f, 0.548434f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            85645.585938f, 0.009334f, 0.009672f, 974.736084f, 0.283336f,
            61559.132813f, 0.006708f, 0.006951f, 722.907288f, 0.665559f,
            50557.976563f, 0.005508f, 0.005707f, 553.873352f, 0.659528f,
            41836.109375f, 0.004556f, 0.004722f, 479.539886f, 0.546652f,
            35293.832031f, 0.003843f, 0.003982f, 449.315521f, 0.458031f,
            30876.058594f, 0.003361f, 0.003482f, 414.814423f, 0.501677f,
            26548.656250f, 0.002888f, 0.002993f, 439.425323f, 0.476335f,
            22391.257813f, 0.002435f, 0.002523f, 519.752808f, 0.305090f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            118378.773438f, 0.012996f, 0.013276f, 848.039063f, 0.595784f,
            72598.562500f, 0.007969f, 0.008141f, 549.577759f, 0.422119f,
            52919.187500f, 0.005807f, 0.005933f, 494.619202f, 0.158978f,
            41900.156250f, 0.004597f, 0.004696f, 478.080780f, 0.386817f,
            33295.687500f, 0.003652f, 0.003731f, 534.190430f, 0.370020f,
            28785.074219f, 0.003156f, 0.003224f, 517.842896f, 0.537391f,
            24476.859375f, 0.002683f, 0.002740f, 559.308838f, 0.535835f,
            22190.798828f, 0.002431f, 0.002483f, 531.698608f, 0.629309f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            70405.882813f, 0.007784f, 0.007839f, 582.621094f, 0.503437f,
            48464.902344f, 0.005357f, 0.005395f, 606.430725f, 0.611106f,
            37528.800781f, 0.004147f, 0.004177f, 625.086609f, 0.640987f,
            30957.181641f, 0.003420f, 0.003444f, 632.084534f, 0.662453f,
            26557.896484f, 0.002933f, 0.002954f, 627.860413f, 0.686257f,
            22324.916016f, 0.002464f, 0.002482f, 682.466614f, 0.628115f,
            20077.960938f, 0.002215f, 0.002231f, 669.410034f, 0.658915f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            92170.617188f, 0.010265f, 0.010192f, 938.255981f, 0.435386f,
            52896.441406f, 0.005890f, 0.005848f, 871.744934f, 0.562675f,
            39756.425781f, 0.004426f, 0.004394f, 833.295227f, 0.607677f,
            33097.402344f, 0.003684f, 0.003658f, 777.841919f, 0.674509f,
            26708.628906f, 0.002972f, 0.002951f, 811.561890f, 0.612967f,
            24334.724609f, 0.002707f, 0.002687f, 739.247620f, 0.702966f,
            22088.482422f, 0.002456f, 0.002438f, 696.214050f, 0.736677f,
            19893.539063f, 0.002211f, 0.002195f, 681.134094f, 0.744979f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            46350.406250f, 0.005197f, 0.005087f, 990.793579f, 0.157359f,
            35370.171875f, 0.003965f, 0.003881f, 950.707092f, 0.392483f,
            28834.128906f, 0.003232f, 0.003163f, 926.292725f, 0.468239f,
            24482.242188f, 0.002743f, 0.002685f, 906.699768f, 0.511554f,
            22175.644531f, 0.002484f, 0.002431f, 847.919128f, 0.614729f,
            19964.589844f, 0.002235f, 0.002188f, 818.931702f, 0.650527f,
            17808.767578f, 0.001993f, 0.001951f, 816.981445f, 0.649578f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            129416.523438f, 0.014616f, 0.014103f, 838.234070f, 0.591684f,
            57285.804688f, 0.006468f, 0.006242f, 795.426819f, 0.620137f,
            35314.144531f, 0.003987f, 0.003847f, 951.998474f, 0.372398f,
            28702.027344f, 0.003239f, 0.003126f, 929.994324f, 0.432224f,
            24326.074219f, 0.002745f, 0.002649f, 912.520203f, 0.484594f,
            20128.722656f, 0.002270f, 0.002191f, 952.526245f, 0.388535f,
            17944.888672f, 0.002023f, 0.001952f, 935.899048f, 0.442451f,
            17700.519531f, 0.001995f, 0.001925f, 823.020508f, 0.635990f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            98723.656250f, 0.011226f, 0.010679f, 906.507751f, 0.514077f,
            74671.210938f, 0.008489f, 0.008076f, 517.682983f, 0.508701f,
            41989.574219f, 0.004773f, 0.004540f, 774.333618f, 0.630150f,
            28766.078125f, 0.003269f, 0.003110f, 928.317810f, 0.458503f,
            22379.988281f, 0.002542f, 0.002419f, 998.055481f, 0.051893f,
            20036.591797f, 0.002275f, 0.002165f, 956.673584f, 0.350264f,
            17836.689453f, 0.002025f, 0.001926f, 940.417236f, 0.413121f,
            15723.994141f, 0.001784f, 0.001697f, 952.167175f, 0.385829f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            83505.242188f, 0.009559f, 0.008965f, 988.331909f, 0.177425f,
            65908.484375f, 0.007544f, 0.007075f, 653.118713f, 0.680541f,
            52923.191406f, 0.006056f, 0.005680f, 494.202148f, 0.224752f,
            35391.160156f, 0.004049f, 0.003797f, 698.526123f, 0.652526f,
            24422.177734f, 0.002793f, 0.002619f, 908.882813f, 0.510390f,
            20056.619141f, 0.002293f, 0.002150f, 955.717285f, 0.361318f,
            17820.660156f, 0.002037f, 0.001910f, 942.167908f, 0.398036f,
            15675.884766f, 0.001791f, 0.001679f, 956.253662f, 0.351583f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            116242.437500f, 0.013396f, 0.012384f, 851.377930f, 0.599443f,
            57369.832031f, 0.006610f, 0.006111f, 794.207092f, 0.615619f,
            50597.996094f, 0.005829f, 0.005389f, 552.038879f, 0.648187f,
            41952.195313f, 0.004831f, 0.004467f, 475.427643f, 0.304585f,
            28935.013672f, 0.003331f, 0.003080f, 717.631592f, 0.624421f,
            22203.683594f, 0.002555f, 0.002363f, 846.158508f, 0.615924f,
            17872.755859f, 0.002056f, 0.001901f, 938.786865f, 0.427732f,
            15683.902344f, 0.001803f, 0.001667f, 955.618896f, 0.357555f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            100924.007813f, 0.011706f, 0.010669f, 896.910889f, 0.535234f,
            52820.417969f, 0.006126f, 0.005583f, 873.124451f, 0.577471f,
            46247.761719f, 0.005362f, 0.004887f, 662.374329f, 0.696745f,
            41792.074219f, 0.004844f, 0.004415f, 481.491882f, 0.671304f,
            35337.878906f, 0.004095f, 0.003732f, 447.731934f, 0.418746f,
            26658.039063f, 0.003088f, 0.002815f, 624.678284f, 0.631837f,
            20036.722656f, 0.002320f, 0.002115f, 814.629395f, 0.646440f,
            15764.085938f, 0.001825f, 0.001663f, 950.709167f, 0.394565f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            90038.281250f, 0.010511f, 0.009444f, 949.578735f, 0.385274f,
            48511.078125f, 0.005662f, 0.005087f, 950.875061f, 0.387508f,
            41993.574219f, 0.004901f, 0.004403f, 773.450073f, 0.642448f,
            37664.906250f, 0.004394f, 0.003948f, 621.000061f, 0.580130f,
            35245.777344f, 0.004111f, 0.003693f, 451.882599f, 0.644038f,
            29005.388672f, 0.003382f, 0.003038f, 508.276550f, 0.189165f,
            24432.779297f, 0.002847f, 0.002558f, 560.284973f, 0.625429f,
            17896.968750f, 0.002085f, 0.001873f, 811.093079f, 0.640437f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            111957.757813f, 0.013154f, 0.011649f, 861.751465f, 0.592252f,
            46450.437500f, 0.005456f, 0.004832f, 989.162231f, 0.183322f,
            39700.398438f, 0.004662f, 0.004129f, 833.194275f, 0.632952f,
            35431.191406f, 0.004160f, 0.003684f, 696.673279f, 0.655557f,
            33111.492188f, 0.003886f, 0.003442f, 541.765259f, 0.685477f,
            28973.343750f, 0.003400f, 0.003011f, 509.339478f, 0.255256f,
            26600.751953f, 0.003120f, 0.002763f, 438.383209f, 0.452246f,
            22238.908203f, 0.002607f, 0.002309f, 527.905212f, 0.614149f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            101072.031250f, 0.011949f, 0.010432f, 896.629761f, 0.535655f,
            63879.855469f, 0.007551f, 0.006592f, 685.437378f, 0.662679f,
            37515.273438f, 0.004434f, 0.003871f, 892.341553f, 0.538815f,
            33257.523438f, 0.003929f, 0.003430f, 771.756165f, 0.649432f,
            30989.216797f, 0.003660f, 0.003196f, 629.238464f, 0.688821f,
            28777.064453f, 0.003398f, 0.002966f, 519.286926f, 0.640594f,
            26568.693359f, 0.003136f, 0.002738f, 439.535583f, 0.560479f,
            22467.431641f, 0.002650f, 0.002314f, 514.761719f, 0.247336f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            92390.648438f, 0.010991f, 0.009458f, 936.745361f, 0.438961f,
            59482.488281f, 0.007075f, 0.006088f, 756.560913f, 0.678715f,
            35402.187500f, 0.004210f, 0.003623f, 949.402954f, 0.381982f,
            31163.917969f, 0.003705f, 0.003188f, 844.716003f, 0.589117f,
            28931.009766f, 0.003438f, 0.002959f, 717.676575f, 0.643960f,
            26794.234375f, 0.003183f, 0.002739f, 617.761841f, 0.566249f,
            26456.488281f, 0.003142f, 0.002704f, 445.853699f, 0.731937f,
            24311.652344f, 0.002886f, 0.002483f, 394.183502f, 0.634747f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            85881.617188f, 0.010279f, 0.008718f, 973.452576f, 0.279285f,
            55201.156250f, 0.006606f, 0.005603f, 830.494690f, 0.615464f,
            35482.230469f, 0.004245f, 0.003601f, 947.812805f, 0.402083f,
            30915.726563f, 0.003698f, 0.003137f, 851.599915f, 0.599310f,
            28686.748047f, 0.003430f, 0.002910f, 727.014893f, 0.727482f,
            26541.875000f, 0.003172f, 0.002691f, 628.806702f, 0.746572f,
            24448.808594f, 0.002921f, 0.002478f, 560.569885f, 0.658111f,
            22383.238281f, 0.002673f, 0.002267f, 519.012756f, 0.426752f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            101260.054688f, 0.012192f, 0.010193f, 895.858154f, 0.536146f,
            52896.441406f, 0.006368f, 0.005324f, 871.234497f, 0.575522f,
            48484.910156f, 0.005836f, 0.004879f, 605.155884f, 0.738257f,
            28858.148438f, 0.003472f, 0.002903f, 924.626526f, 0.467282f,
            26640.554688f, 0.003205f, 0.002679f, 814.077576f, 0.651841f,
            24563.050781f, 0.002954f, 0.002469f, 727.822327f, 0.652678f,
            24292.521484f, 0.002920f, 0.002441f, 569.460754f, 0.773562f,
            22242.917969f, 0.002672f, 0.002234f, 529.455200f, 0.666417f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            94715.023438f, 0.011472f, 0.009453f, 925.031677f, 0.469311f,
            48799.167969f, 0.005909f, 0.004869f, 945.782837f, 0.416601f,
            46263.769531f, 0.005601f, 0.004616f, 663.092590f, 0.755872f,
            28822.121094f, 0.003489f, 0.002875f, 925.728394f, 0.442910f,
            26508.414063f, 0.003208f, 0.002643f, 818.064087f, 0.627599f,
            24366.769531f, 0.002947f, 0.002429f, 738.946289f, 0.719628f,
            22336.937500f, 0.002701f, 0.002226f, 681.177246f, 0.675083f,
            22110.615234f, 0.002672f, 0.002202f, 535.740662f, 0.773290f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            88302.000000f, 0.010757f, 0.008736f, 959.667908f, 0.362094f,
            46630.492188f, 0.005680f, 0.004613f, 985.723938f, 0.221253f,
            44078.648438f, 0.005368f, 0.004359f, 718.146790f, 0.732013f,
            26876.626953f, 0.003272f, 0.002657f, 996.410706f, 0.092615f,
            24502.263672f, 0.002982f, 0.002422f, 906.272583f, 0.514388f,
            22460.048828f, 0.002733f, 0.002219f, 833.770447f, 0.598985f,
            22172.636719f, 0.002697f, 0.002190f, 688.961243f, 0.745565f,
            20226.300781f, 0.002459f, 0.001997f, 659.399597f, 0.631061f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            83953.312500f, 0.010286f, 0.008233f, 985.919250f, 0.192618f,
            59758.574219f, 0.007321f, 0.005859f, 752.509277f, 0.650407f,
            41933.542969f, 0.005136f, 0.004111f, 775.472717f, 0.687579f,
            37885.074219f, 0.004639f, 0.003713f, 613.489502f, 0.550629f,
            24442.199219f, 0.002992f, 0.002395f, 908.847900f, 0.479791f,
            22267.775391f, 0.002725f, 0.002181f, 843.145813f, 0.622133f,
            22064.437500f, 0.002699f, 0.002160f, 695.854736f, 0.724373f,
            20057.916016f, 0.002452f, 0.001963f, 670.688538f, 0.733831f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            97047.390625f, 0.011958f, 0.009432f, 914.239685f, 0.475033f,
            57453.859375f, 0.007078f, 0.005583f, 792.837830f, 0.676108f,
            39816.457031f, 0.004904f, 0.003868f, 830.165710f, 0.632393f,
            37560.828125f, 0.004625f, 0.003648f, 624.440063f, 0.767034f,
            22544.164063f, 0.002775f, 0.002189f, 990.844421f, 0.182595f,
            22191.666016f, 0.002731f, 0.002154f, 847.206299f, 0.584623f,
            20128.890625f, 0.002476f, 0.001953f, 807.039001f, 0.657802f,
            19941.648438f, 0.002452f, 0.001934f, 676.291504f, 0.752837f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            90682.382813f, 0.011237f, 0.008734f, 946.243774f, 0.409239f,
            55241.171875f, 0.006844f, 0.005319f, 828.721558f, 0.630389f,
            37735.386719f, 0.004674f, 0.003633f, 886.653625f, 0.553447f,
            35495.242188f, 0.004395f, 0.003416f, 693.488708f, 0.725021f,
            22528.146484f, 0.002789f, 0.002168f, 991.519531f, 0.158917f,
            20284.945313f, 0.002510f, 0.001951f, 943.742249f, 0.418965f,
            20028.707031f, 0.002478f, 0.001926f, 814.542664f, 0.646908f,
            18145.537109f, 0.002244f, 0.001744f, 794.573486f, 0.617869f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            86365.695313f, 0.010761f, 0.008241f, 970.539612f, 0.303192f,
            53088.500000f, 0.006613f, 0.005065f, 866.579285f, 0.561085f,
            35726.355469f, 0.004450f, 0.003408f, 941.815308f, 0.425623f,
            33521.726563f, 0.004174f, 0.003197f, 763.399780f, 0.636024f,
            33155.539063f, 0.004127f, 0.003161f, 539.833984f, 0.786537f,
            20196.820313f, 0.002513f, 0.001925f, 949.126587f, 0.381909f,
            19976.611328f, 0.002485f, 0.001903f, 815.411133f, 0.604730f,
            17965.125000f, 0.002234f, 0.001711f, 806.143616f, 0.658648f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            97355.437500f, 0.012196f, 0.009203f, 912.112854f, 0.496291f,
            50975.843750f, 0.006385f, 0.004818f, 904.751282f, 0.487790f,
            35614.296875f, 0.004460f, 0.003366f, 943.157227f, 0.394260f,
            33273.535156f, 0.004166f, 0.003144f, 771.913330f, 0.692525f,
            31157.396484f, 0.003899f, 0.002943f, 621.293640f, 0.725454f,
            20208.837891f, 0.002528f, 0.001908f, 948.122070f, 0.382684f,
            18085.144531f, 0.002262f, 0.001707f, 926.634644f, 0.467576f,
            17872.914063f, 0.002234f, 0.001686f, 811.104370f, 0.653333f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            93046.757813f, 0.011718f, 0.008713f, 932.353882f, 0.437750f,
            48891.195313f, 0.006156f, 0.004578f, 942.344055f, 0.396710f,
            33653.289063f, 0.004237f, 0.003150f, 998.464539f, 0.051239f,
            31292.015625f, 0.003938f, 0.002928f, 839.201843f, 0.616365f,
            30985.212891f, 0.003899f, 0.002899f, 627.944031f, 0.767816f,
            20365.060547f, 0.002561f, 0.001905f, 940.165649f, 0.430780f,
            18009.005859f, 0.002264f, 0.001684f, 931.915344f, 0.439841f,
            17824.802734f, 0.002240f, 0.001666f, 815.225342f, 0.615193f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            88786.078125f, 0.011241f, 0.008234f, 956.900269f, 0.358564f,
            46850.562500f, 0.005930f, 0.004344f, 981.729614f, 0.226501f,
            44322.773438f, 0.005609f, 0.004109f, 710.775269f, 0.730680f,
            31143.902344f, 0.003940f, 0.002887f, 844.567139f, 0.597400f,
            29027.113281f, 0.003672f, 0.002690f, 711.614685f, 0.715386f,
            28777.064453f, 0.003639f, 0.002665f, 516.256714f, 0.792316f,
            18000.990234f, 0.002275f, 0.001667f, 932.347778f, 0.424635f,
            17812.775391f, 0.002250f, 0.001648f, 814.493042f, 0.588070f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            97731.500000f, 0.012438f, 0.008975f, 910.695313f, 0.506175f,
            55697.312500f, 0.007087f, 0.005114f, 821.538208f, 0.630870f,
            42261.714844f, 0.005376f, 0.003880f, 766.242249f, 0.700471f,
            29194.406250f, 0.003713f, 0.002679f, 913.587097f, 0.498999f,
            28878.955078f, 0.003672f, 0.002650f, 717.521912f, 0.720396f,
            26862.332031f, 0.003414f, 0.002464f, 613.906799f, 0.708566f,
            18061.101563f, 0.002295f, 0.001656f, 928.389221f, 0.454412f,
            15924.453125f, 0.002022f, 0.001459f, 938.855896f, 0.432833f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            93522.828125f, 0.011963f, 0.008504f, 931.310242f, 0.455231f,
            53584.656250f, 0.006853f, 0.004872f, 858.381653f, 0.587339f,
            40252.679688f, 0.005147f, 0.003659f, 819.072510f, 0.634700f,
            29086.322266f, 0.003718f, 0.002643f, 917.102234f, 0.467127f,
            26972.912109f, 0.003447f, 0.002450f, 799.959656f, 0.647898f,
            26714.119141f, 0.003413f, 0.002426f, 621.674316f, 0.773894f,
            24757.373047f, 0.003161f, 0.002247f, 543.108398f, 0.589267f,
            15872.333984f, 0.002026f, 0.001440f, 942.881653f, 0.404303f,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            POSITIVE_INFINITY, 0, 0, 0, 0,
            91254.468750f, 0.011731f, 0.008214f, 942.804382f, 0.395050f,
            51572.031250f, 0.006629f, 0.004642f, 895.538391f, 0.528635f,
            40076.589844f, 0.005150f, 0.003606f, 823.183044f, 0.609252f,
            29150.373047f, 0.003745f, 0.002622f, 915.015076f, 0.485719f,
            26824.751953f, 0.003445f, 0.002412f, 806.237488f, 0.657317f,
            24915.552734f, 0.003199f, 0.002240f, 710.825073f, 0.625599f,
            24621.123047f, 0.003160f, 0.002213f, 551.045471f, 0.747781f,
            15872.333984f, 0.002036f, 0.001426f, 942.660400f, 0.396299f
    };

}
